<?php

namespace common\logic\PointSale\PointSale;

use common\helpers\GlobalParam;
use common\logic\BaseService;
use common\logic\BuilderInterface;
use common\logic\Distribution\Distribution\Distribution;
use common\logic\Producer\Producer\Producer;
use common\logic\RepositoryInterface;

class PointSaleRepository extends BaseService implements RepositoryInterface
{
    public function getDefaultOptionsSearch(): array
    {
        return [
            'with' => [],
            'join_with' => [],
            'orderby' => 'is_bread_box ASC, name ASC',
            'attribute_id_producer' => 'point_sale.id_producer'
        ];
    }

    public function findOnePointSaleById(int $id): ?PointSale
    {
        return PointSale::searchOne(['id' => $id]);
    }

    public function findPointSalesByDistribution(Distribution $distribution)
    {
        return PointSale::find()
            ->with(['pointSaleDistribution' => function ($q) use ($distribution) {
                $q->where(['id_distribution' => $distribution->id]);
            }])
            ->where([
                'id_producer' => $distribution->producer->id,
            ])
            ->all();
    }

    /**
     * Retourne le nombre de points de vente pour le producteur courant.
     */
    public static function countPointSales(): int
    {
        return PointSale::searchCount(['id_producer' => GlobalParam::getCurrentProducerId()]);
    }

    public function findPointSales()
    {
        return PointSale::find()
            ->where('id_producer = ' . GlobalParam::getCurrentProducerId())
            ->all();;
    }

    public function queryPointSalesPublic(Producer $producer)
    {
        return PointSale::find()
            ->where([
                'id_producer' => $producer->id,
                'restricted_access' => 0,
                'status' => 1
            ])->orderBy(
                'code ASC, restricted_access ASC, is_bread_box ASC, `default` DESC, name ASC'
            );
    }

    public function populatePointSaleDropdownList(): array
    {
        $pointSalesArrayDropdown = ['' => '--'];
        $pointSalesArray = $this->findPointSales();

        foreach ($pointSalesArray as $pointSale) {
            $pointSalesArrayDropdown[$pointSale['id']] = $pointSale['name'];
        }

        return $pointSalesArrayDropdown;
    }
}